@@ -1,6 +1,6 @@
 package Net::Appliance::Session::Transport;
 {
-  $Net::Appliance::Session::Transport::VERSION = '3.122100';
+  $Net::Appliance::Session::Transport::VERSION = '3.122530';
 }
 
 {
@@ -57,7 +57,7 @@ sub connect {
     # optionally, log in to the remote host
     if ($self->do_login and not $self->prompt_looks_like('prompt')) {
 
-        if ($self->nci->phrasebook->has_macro('user')
+        if ($self->nci->phrasebook->has_prompt('user')
             and $self->prompt_looks_like('user')) {
             die 'a set username is required to connect to this host'
                 if not $self->has_username;
